@@ -9,6 +9,7 @@ import Queue as queue
 import warnings
 import binascii
 import os
+import time
 import struct
 import atexit
 import glob
@@ -198,7 +199,6 @@ class MSTPDirector(asyncore.dispatcher, Server, ServiceAccessPoint):
         libmstp_path=os.path.join(dirname, "libmstp_agent.so")
         mstp_lib = cdll.LoadLibrary(libmstp_path)
         MSTPDirector.mstp_lib = mstp_lib
-        mstp_lib.start_server(mstp_dir)
 
 
         self.bind(my_addr)
@@ -213,9 +213,6 @@ class MSTPDirector(asyncore.dispatcher, Server, ServiceAccessPoint):
         # start with an empty peer pool
         self.peers = {}
 
-        # server to send the MSTP PDU's
-        self.server_address = '{}/mstp_server'.format(mstp_dir)
-        self.socket.connect(self.server_address)
 
         #send control stuff
         # 0x5 - Mac Address
@@ -228,8 +225,15 @@ class MSTPDirector(asyncore.dispatcher, Server, ServiceAccessPoint):
         baud_rate = self.localDevice._baudrate
         maxinfo = self.localDevice._maxinfo
         buf = struct.pack('iiii', mac, max_masters, baud_rate, maxinfo);
-        mstp_lib.set_interface_params(interface_filename, buf, interface_devname)
 
+        mstp_lib.init(buf, interface_devname, mstp_dir)
+
+        # to ensure that the server is ready
+        time.sleep(0.5)
+
+        # server to send the MSTP PDU's
+        self.server_address = '{}/mstp_server'.format(mstp_dir)
+        self.socket.connect(self.server_address)
 
     @staticmethod
     @atexit.register
